==> OlinkAnalyze_4.0.1.tar.gz: OlinkAnalyze/R/globals.R <==
# Global Variables Defined

utils::globalVariables(unique(c(
  "plate", "SampleID", "group.var", "percent", "unique.id", "column", "OlinkID", "NPX", "n_na", "SampleID",
  "Index", "n_levels", ".", "Assay", "UniProt", "Panel", "term", "p.value", "Adjusted_pval", "Threshold", "sumsq",
  "meansq", "statistic", "lower.CL", "upper.CL", "contrast", "estimate", "conf.low", "conf.high", "Name_OID",
  "QC_Warning", "sample_median", "median_high", "median_low", "iqr_low", "iqr_high", "Outlier", "LOD", "Warnings",
  "Outliers", "PercAssaysBelowLOD", "MeanNPX", "desc", "Order", "emmean", "everything", "Reference_NPX",
  "Assay_Median", "LOD", "Project", "Diff", "Median", "n_colors", "assay_var", "pca_colors", "desc", "abs_loading",
  "variables", "well", "scramble", ":=", "estimate1", "estimate2", "1", "Name", "Plate ID", "MissingFreq", "Unit",
  "Assay_Warning", "Panel_Version", "QC Warning", "Name_Assay", "PlateID", "Adj_factor", "Panel_End", "Panel_Start",
  "SampleIDPlot", "PCX_low", "PCX_high", "PCY_low", "PCY_high", "BgRatio", "Count", "Description", "Detected",
  "GeneRatio", "NES", "Pathway", "geneList", "Sum","gene_symbol", "gs_name", "gs_subcat", ".y.", "SE", "df", "group1",
  "group2", "method", "p", "p.adj", "parameter", "t.ratio", "Assay_OlinkID", "C1", "C2", "N", "NrNA", "Star",
  "SumNA", "c.sort", "colors", "id", "maxNPX", "pvalue","rangeNPX", "rowNum", "tmp", "x.m", "x.vals", "y.anchor",
  "SubjectID", "study", "SubjectID_old", "Friedman_remove", "P.adj", "Comparison", "Z", "number of NA values", "umapX_high",
  "umapX_low", "umapY_high", "umapY_low", "LX", "LY", "PCX", "PCY", "rowname", "Normalization", "Quantified_value", "v1",
  "v2", "v", "v_name", "duplicateID", "SampleID_df1", "name", "data", "normalize_to", "PlateID1", "QC_Warning1", "V1", "V2",
  "cols", "ID", "AssayQC", "AssayType", "Block", "DataAnalysisRefID", "ExploreVersion", "ExtNPX", "PCNormalizedNPX", "SampleQC", "SampleType", "WellID",
  "Max LOD", "Plate LOD", "Plate_LOD", "Normalization_df1", "Normalization_df2",   "Max_LOD", "maxLOD", "plateLOD", ".env", ".data", "PCNormalizedLOD"
)))

==> OlinkAnalyze_4.4.0.tar.gz: OlinkAnalyze/R/globals.R <==
# Global Variables Defined

utils::globalVariables(unique(c(
  "plate", "SampleID", "group.var", "percent", "unique.id", "column", "OlinkID", "NPX", "n_na", "SampleID",
  "Index", "n_levels", ".", "Assay", "UniProt", "Panel", "term", "p.value", "Adjusted_pval", "Threshold", "sumsq",
  "meansq", "statistic", "lower.CL", "upper.CL", "contrast", "estimate", "conf.low", "conf.high", "Name_OID",
  "QC_Warning", "sample_median", "median_high", "median_low", "iqr_low", "iqr_high", "Outlier", "LOD", "Warnings",
  "Outliers", "PercAssaysBelowLOD", "MeanNPX", "desc", "Order", "emmean", "everything", "Reference_NPX",
  "Assay_Median", "LOD", "Project", "Diff", "Median", "n_colors", "assay_var", "pca_colors", "desc", "abs_loading",
  "variables", "well", "scramble", ":=", "estimate1", "estimate2", "1", "Name", "Plate ID", "MissingFreq", "Unit",
  "Assay_Warning", "Panel_Version", "QC Warning", "Name_Assay", "PlateID", "Adj_factor", "Panel_End", "Panel_Start",
  "SampleIDPlot", "PCX_low", "PCX_high", "PCY_low", "PCY_high", "BgRatio", "Count", "Description", "Detected",
  "GeneRatio", "NES", "Pathway", "geneList", "Sum","gene_symbol", "gs_name", "gs_subcollection", ".y.", "SE", "df", "group1",
  "group2", "method", "p", "p.adj", "parameter", "t.ratio", "Assay_OlinkID", "C1", "C2", "N", "NrNA", "Star",
  "SumNA", "c.sort", "colors", "id", "maxNPX", "pvalue","rangeNPX", "rowNum", "tmp", "x.m", "x.vals", "y.anchor",
  "SubjectID", "study", "SubjectID_old", "Friedman_remove", "P.adj", "Comparison", "Z", "number of NA values", "umapX_high",
  "umapX_low", "umapY_high", "umapY_low", "LX", "LY", "PCX", "PCY", "rowname", "Normalization", "Quantified_value", "v1",
  "v2", "v", "v_name", "duplicateID", "SampleID_df1", "name", "data", "normalize_to", "PlateID1", "QC_Warning1", "V1", "V2",
  "cols", "ID", "AssayQC", "AssayType", "Block", "DataAnalysisRefID", "ExploreVersion", "ExtNPX", "PCNormalizedNPX", "SampleQC", "SampleType", "WellID",
  "Max LOD", "Plate LOD", "Plate_LOD", "Normalization_df1", "Normalization_df2",   "Max_LOD", "maxLOD", "plateLOD", ".env", ".data", "PCNormalizedLOD"
)))
